/*
** Generated by X-Designer
*/

/*
** X-Designer-generated prelude.
** Do not edit lines before "End of X-Designer generated prelude"
** Lines beginning ** X-Designer Stub indicate a stub
** which will not be output on re-generation
*/

/*
**LIBS: -lXm -lXt -lX11
*/

#include <stdlib.h>
#include <X11/Xatom.h>
#include <X11/Intrinsic.h>
#include <X11/Shell.h>

#include <Xm/Xm.h>
#include <Xm/DrawingA.h>

#include "popups21.h"



/* End of X-Designer generated prelude */
/*
** X-Designer Stub PopupHandlerCallback
*/

#ifndef   _NO_PROTO
void PopupHandlerCallback(Widget w, XtPointer client_data, XtPointer xt_call_data)
#else  /* _NO_PROTO */
void PopupHandlerCallback(w, client_data, call_data)
	Widget    w ;
	XtPointer client_data ;
	XmPopupHandlerCallbackStruct * call_data ;
#endif /* _NO_PROTO */
{
#ifndef   _NO_PROTO
	XmPopupHandlerCallbackStruct *call_data = (XmPopupHandlerCallbackStruct *) xt_call_data ;
#endif /* _NO_PROTO */

	XButtonPressedEvent *be = (XButtonPressedEvent *) call_data->event ;

	/* This is so much simpler */

	if (((be->x + be->y) % 2) == 0)
		call_data->menuToPost = menuA ;
	else
		call_data->menuToPost = menuB ;

	call_data->postIt = True ;
}

